trailing_stop_calculate_with_last

Function trailing_stop_calculate_with_last 

pub fn trailing_stop_calculate_with_last(
    price_increment: Price,
    trailing_offset_type: TrailingOffsetType,
    side: OrderSideSpecified,
    offset: Decimal,
    last: Price,
) -> Result<Price>
Calculates the trailing stop price using the last traded price.

Errors

Returns an error if the offset type is unsupported or the calculated price cannot be represented as a [Price].